@@ -6,19 +6,19 @@ from .constants import Patterns
 
 
 class LuaParser(RegexParser):
-    filters = frozenset((
+    FILTERS = frozenset((
         lambda file_path: file_path[-9:] != r"\init.lua",
         lambda file_path: file_path[-14:] != r"\constants.lua",
         lambda file_path: file_path[-11:] != r"\config.lua"
     ))
 
-    _node_endings = (
+    NODE_ENDINGS = (
         r"\init.lua",
         ".lua"
     )  # TODO: Determine correct ordering to match Lua's
 
-    _patterns = {
-        **Patterns.require
+    PATTERNS = {
+        **Patterns.REQUIRE
     }
 
     @classmethod
